ChatNotifier class
Methods
-
add(Message message)
→ void
-
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
clean()
→ void
-
-
clear()
→ void
-
Remove all callbacks.
inherited
-
deregister(String key)
→ void
-
Deregister a callback by its key.
you can use removeListener() as well
inherited
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notify()
→ void
-
Instead of notifyListeners(), call notify() which triggers
all registered callbacks and then notifies Flutter.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
register(String key, GaanaCallback callback)
→ void
-
Register a callback with a unique key.
you can use addListener() as well
inherited
-
remove(Message message)
→ void
-
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited