OldUsersNotifier class
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
set(List<String> newUsers)
→ void
-
Updates the list and notifies listeners.
-
shuffle()
→ void
-
Shuffles the list and notifies listeners.
-
toString()
→ String
-
A string representation of this object.
inherited