PetrolUseCase class
Constructors
- PetrolUseCase({required PlotRepository repository, required PlotNotifier plotNotifier})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- plotNotifier → PlotNotifier
-
final
- repository → PlotRepository
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isRunning(
) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
) → void - Initiates the process:
-
stop(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited