GaanaNotifier class
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
hasListeners
→ bool
Whether any listeners are currently registered.
no setter inherited
key
→ String
final
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
addListener (VoidCallback listener )
→ void
Register a closure to be called when the object changes.
inherited
clear ()
→ void
Remove all callbacks.
deregister (String key )
→ void
Deregister a callback by its key.
you can use removeListener() as well
dispose ()
→ void
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify ()
→ void
Instead of notifyListeners(), call notify() which triggers
all registered callbacks and then notifies Flutter.
notifyListeners ()
→ void
Call all the registered listeners.
inherited
register (String key , GaanaCallback callback )
→ void
Register a callback with a unique key.
you can use addListener() as well
removeListener (VoidCallback listener )
→ void
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
toString ()
→ String
A string representation of this object.
inherited